Index: pkg/analysis_server/lib/src/services/index/local_index.dart |
diff --git a/pkg/analysis_server/lib/src/services/index/local_index.dart b/pkg/analysis_server/lib/src/services/index/local_index.dart |
index e9deeda04475f6a6e9d1818f7c6fc6617366e4d5..a11db6d90d51a5d5cd2fabef5fe79fa452767e0f 100644 |
--- a/pkg/analysis_server/lib/src/services/index/local_index.dart |
+++ b/pkg/analysis_server/lib/src/services/index/local_index.dart |
@@ -44,15 +44,15 @@ class LocalIndex extends Index { |
/** |
* Returns a `Future<List<Location>>` that completes with the list of |
* [Location]s of the given [relationship] with the given [element]. |
* |
* For example, if the [element] represents a function and the [relationship] |
* is the `is-invoked-by` relationship, then the locations will be all of the |
* places where the function is invoked. |
*/ |
@override |
- Future<List<Location>> getRelationships( |
- Element element, Relationship relationship) { |
+ Future<List<LocationImpl>> getRelationships( |
+ Element element, RelationshipImpl relationship) { |
return _store.getRelationships(element, relationship); |
} |
@@ -44,15 +44,15 @@ class LocalIndex extends Index { |
/** |
* Returns a `Future<List<Location>>` that completes with the list of |
- * [Location]s of the given [relationship] with the given [element]. |
+ * [LocationImpl]s of the given [relationship] with the given [element]. |
* |
* For example, if the [element] represents a function and the [relationship] |